//Tamanooki code and pixel art by Jae van den Heuvel With help by Jorn Uffing

//With include you can use an existing library in your code so you don't have to write everything yourself
#include "Arduino_SensorKit.h" //This library is needed for the accelerometer I used
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h> // wire.h and both adafruit libraries are used by my screen
#include "pitches.h" //This library is used by the buzzer and makes it easy to use notes
#include <CuteBuzzerSounds.h> //This library has a bunch of cute sounds that I used as reactions
#include "nook.h" //This is the file I made to contain all my images


#define SCREEN_WIDTH 128  // OLED display width,  in pixels
#define SCREEN_HEIGHT 64  // OLED display height, in pixels
#define button1 4
#define button2 2 
#define BUZZER 5

// declare an SSD1306 display object connected to I2C
Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);


//for reading the pushbutton status
int button_state = 0;
int button_money = 0;

//xyz axis floats for accelerometer
float xNow;
float xPrev;
float yNow;
float yPrev;
float zNow;
float zPrev;
float threshold = 1; // The threshold looks at the difference between the readings of Now and Prev, if the difference is equal to 1 Tom reacts

void setup() {
  Serial.begin(9600);
  Accelerometer.begin(); //This is used to activate the accelerometer

  // initialize the pushbutton pin as an input:
  pinMode(button1, INPUT);
  pinMode(button2, INPUT);
  pinMode(BUZZER, OUTPUT);
  cute.init(BUZZER);

  xNow = Accelerometer.readX();
  xPrev = Accelerometer.readX();

  yNow = Accelerometer.readY();
  yPrev = Accelerometer.readY();

  zNow = Accelerometer.readZ();
  zPrev = Accelerometer.readZ();

  // initialize OLED display with address 0x3C for 128x64
  if (!oled.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("SSD1306 allocation failed"));
    while (true)
      ;
  }

  delay(2000);  // wait for initializing
  oled.setCursor(0, 0);
}

//neutral animation
void tomNorm() {

  oled.clearDisplay(); //Clears the display so the images always work

  // display neutral tom
  oled.drawBitmap(0, 0, NeutralTom, 128, 64, WHITE); //Draws the bitmap of the image
  oled.display();
  delay(100); //The delay is used to make the animations flow correctly
  oled.clearDisplay();
}

// happy animation
void tomHappy() {

  // display normal tom
  oled.drawBitmap(0, 0, NormalTom, 128, 64, WHITE);
  oled.display();
  delay(100);
  cute.play(S_HAPPY);  //plays a happy sound on the buzzer

  oled.clearDisplay();

  // display happy tom
  oled.drawBitmap(0, 0, HappyTom, 128, 64, WHITE);
  oled.display();
  delay(500);
}

//this button plays the happy animation
void happyButton() {

  button_state = digitalRead(button1);
  oled.clearDisplay();

  //if the button is pressed (button_state is high) an animation will play
  if (button_state == HIGH) {
    tomHappy();

  } else {
    tomNorm();
  }
}
//money animation
void money() {

  button_money = digitalRead(button2);
  oled.clearDisplay();

  //If this button is pressed tom will recieve some money
  if (button_money == HIGH) {

    // display coins_appear
    oled.drawBitmap(0, 0, CoinsV1, 128, 64, WHITE);
    oled.display();
    delay(10);
    oled.clearDisplay();

    // Play coin sound
    tone(5, NOTE_B5, 100);
    delay(100);
    tone(5, NOTE_E6, 850);
    delay(600);
    noTone(5);

    // display coins_appear_2
    oled.drawBitmap(0, 0, CoinsV2, 128, 64, WHITE);
    oled.display();
    delay(50);
    oled.clearDisplay();

    // display money_falling
    oled.drawBitmap(0, 0, CoinsV3, 128, 64, WHITE);
    oled.display();
    delay(50);
    oled.clearDisplay();

    // display money_falling
    oled.drawBitmap(0, 0, CoinsV4, 128, 64, WHITE);
    oled.display();
    delay(200);
    oled.clearDisplay();

    tomHappy();

  } else {
    tomNorm();
  }
}
//shook animation
void tomShook() {

  oled.clearDisplay();

  // displays Shocked tom start
  oled.drawBitmap(0, 0, ShockTomStart, 128, 64, WHITE);
  oled.display();
  cute.play(S_SURPRISE);
  delay(50);

  oled.clearDisplay();

  // display shocked tom 1
  oled.drawBitmap(0, 0, ShockTom1, 128, 64, WHITE);
  oled.display();
  //delay(50);
  oled.clearDisplay();
}

//tom gets shaken when the difference between now and prev is above the threshold
void xMove() {
  xNow = Accelerometer.readX();
  yNow = Accelerometer.readY();
  zNow = Accelerometer.readZ();

  if (abs(xNow - xPrev) > threshold || abs(yNow - yPrev) > threshold || abs(zNow - zPrev) > threshold) {
    tomShook();

  } else {
    tomNorm();
  }

  xPrev = xNow;
  yPrev = yNow;
  zPrev = zNow;
}
void loop() {
  happyButton();
  money();
  xMove();
}
